/*
	*
	* This file is taken from CoreStats <https://gitlab.com/cubocore/corestats>
	* Further modifications may be done as per the requirements of DesQ
	* All bug repots are to be filed with DesQ and not corestats
	*

	*
	* This program is free software; you can redistribute it and/or modify
	* it under the terms of the GNU General Public License as published by
	* the Free Software Foundation; either version 3 of the License, or
	* at your option, any later version.
	*

	*
	* This program is distributed in the hope that it will be useful,
	* but WITHOUT ANY WARRANTY; without even the implied warranty of
	* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	* GNU General Public License for more details.
	*

	*
	* You should have received a copy of the GNU General Public License
	* along with this program; if not, write to the Free Software
	* Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
	* MA 02110-1301, USA.
	*
*/

#pragma once

#include "DesQUI.hpp"
#include "DesQCircularProgress.hpp"

/*
	*
	* DesQUsagePie class
	*
	* DesQUsagePie is designed to show the current DesQUsage of various system resources
	* like RAM, HDD, etc...
	*
	* A single DesQUsagePie can show data in multiple segments: Usage of 4 partitions of a HDD
	* or usage of RAM and Swap, and so on..
	*
*/

typedef struct pie_resource_value_t {
	qint64 total;
	qint64 used;
} PieResourceValue;
typedef QList<PieResourceValue> PieResourceValues;

class DesQUsagePie : public DesQCircularProgress {
	Q_OBJECT

	public:
		DesQUsagePie( QString resource, int segments, QWidget *parent );

		/* Units */
		void setUnits( DesQCircularProgress::Units units );

		/* Labels for the legends */
		void setLabels( QStringList );

		/* Set the pie values */
		void setValues( PieResourceValues );

	private:
		int mSegments;
		DesQUsagePie::Units mUnits;
		qint64 sizeHint;
		QString resName;

		qint64 mMax;

		PieResourceValues mValues;
		QStringList mLabels;

		int labelHeight = 0;

	protected:
		void paintEvent( QPaintEvent * );
};
